==> segment-wrapper-2.27.0.tgz: package/lib/segmentWrapper.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import { syncPixels } from './syncPixels';
import { getPageReferrer, updatePageReferrer } from './referrer';
import { getConfig } from './getConfig';
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getGdprPrivacyValue } from './tcf';
/* Default properties to be sent on all trackings */

var DEFAULT_PROPERTIES = {
  platform: 'web'
};
/* ServerSide Forwarding values */

var SSF = {
  enabled: 0,
  disabled: 1
};
/* Static anonymousId for users that has not accepted consents */
// const SEGMENT_ID_USER_WITHOUT_CONSENTS = 'id_user_consent_not_agree'

/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */

export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};
/**
 * Get user traits from global analytics object and put in the object
 * @param {string} gdprPrivacyValue Determine if we have user consents
 * @returns {object} User traits with to add
 */

var mergeUserTraits = function mergeUserTraits(gdprPrivacyValue) {
  // TODO: Disabled for now
  // If user has not accepted GDPR then we should use a static anonymousId
  // if (checkGdprIsAccepted(gdprPrivacyValue)) {
  //   return {
  //     anonymousId: SEGMENT_ID_USER_WITHOUT_CONSENTS
  //   }
  // }
  // If we have user consents, then create the user using anonymousId cookie
  var user = window.analytics.user();
  return {
    anonymousId: user.anonymousId(),
    userId: user.id()
  };
};
/**
 * Get AdobeMarketingCloudVisitorId and merge into the integrations object
 * @param {string} gdprPrivacyValue Tell if user has consents to be tracked
 * @returns {Promise<object>} Integrations with the merged Adobe Analytics needed info
 */


var mergeAdobeAnalyticsIntegrations = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(gdprPrivacyValue) {
    var getCustomAdobeVisitorId, marketingCloudVisitorId;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            // TODO: Disabled for now
            // if we don't have the users consents, we remove all the integrations but Adobe Analytics
            // anyway, Adobe Analytics will be activated but without a marketingCloudVisitorId
            // if (!checkGdprIsAccepted(gdprPrivacyValue)) {
            //   return {
            //     All: false,
            //     'Adobe Analytics': true
            //   }
            // }
            getCustomAdobeVisitorId = getConfig('getCustomAdobeVisitorId');

            if (!(typeof getCustomAdobeVisitorId === 'function')) {
              _context.next = 7;
              break;
            }

            _context.next = 4;
            return getCustomAdobeVisitorId();

          case 4:
            _context.t0 = _context.sent;
            _context.next = 10;
            break;

          case 7:
            _context.next = 9;
            return getAdobeMCVisitorID();

          case 9:
            _context.t0 = _context.sent;

          case 10:
            marketingCloudVisitorId = _context.t0;

            if (marketingCloudVisitorId) {
              _context.next = 13;
              break;
            }

            return _context.abrupt("return", {});

          case 13:
            return _context.abrupt("return", {
              'Adobe Analytics': {
                marketingCloudVisitorId: marketingCloudVisitorId
              }
            });

          case 14:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function mergeAdobeAnalyticsIntegrations(_x) {
    return _ref.apply(this, arguments);
  };
}();
/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */


export var decorateContextWithNeededData = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(context) {
    var gdprPrivacyValue, _yield$Promise$all, adobeIntegrations, _yield$Promise$all$, isDMPReady;

    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (context === void 0) {
              context = {};
            }

            _context2.next = 3;
            return getGdprPrivacyValue();

          case 3:
            gdprPrivacyValue = _context2.sent;
            _context2.next = 6;
            return Promise.all([mergeAdobeAnalyticsIntegrations(gdprPrivacyValue) // TODO: Blocking check of DMP is disabled for now
            // checkIsDMPReady()
            ]);

          case 6:
            _yield$Promise$all = _context2.sent;
            adobeIntegrations = _yield$Promise$all[0];
            _yield$Promise$all$ = _yield$Promise$all[1];
            isDMPReady = _yield$Promise$all$ === void 0 ? true : _yield$Promise$all$;
            return _context2.abrupt("return", _extends({}, context, {
              gdpr_privacy: gdprPrivacyValue,
              integrations: _extends({}, context.integrations, adobeIntegrations),
              page: _extends({}, context.page, {
                referrer: getPageReferrer()
              }),
              traits: _extends({}, context.traits, {
                ssf: isDMPReady ? SSF.enabled : SSF.disabled
              }, mergeUserTraits(gdprPrivacyValue))
            }));

          case 11:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function decorateContextWithNeededData(_x2) {
    return _ref2.apply(this, arguments);
  };
}();
/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */

var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  return new Promise(function (resolve, reject) {
    window.analytics.ready( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      var newContext, newProperties, newCallback;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return decorateContextWithNeededData(context);

            case 2:
              newContext = _context3.sent;
              newProperties = _extends({}, getDefaultProperties(), properties);

              newCallback = function newCallback() {
                for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
                  args[_key] = arguments[_key];
                }

                if (callback) callback.apply(void 0, args); // eslint-disable-line standard/no-callback-literal

                getAdobeMCVisitorID().then(function (marketingCloudVisitorId) {
                  return syncPixels(marketingCloudVisitorId).then(function () {
                    resolve.apply(void 0, args);
                  });
                })["catch"](reject);
              };

              window.analytics.track(event, newProperties, newContext, newCallback);

            case 6:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
  });
};
/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var identify = function identify(userId, traits, options, callback) {
  return Promise.resolve(window.analytics.identify(userId, traits, options, callback));
};
/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * It updates automatically the referrer from the context on SPA navigations.
 * @param {string} event The name of the event you’re tracking
 * @param {object} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  updatePageReferrer();
  return track(event, properties, context, callback);
};
/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */


var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};

export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};

==> segment-wrapper-2.28.0.tgz: package/lib/segmentWrapper.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _extends from "@babel/runtime/helpers/esm/extends";
import { syncPixels } from './syncPixels';
import { getPageReferrer, updatePageReferrer } from './referrer';
import { getConfig } from './getConfig';
import { getAdobeMCVisitorID } from './adobeRepository.js';
import { getGdprPrivacyValue } from './tcf';
/* Default properties to be sent on all trackings */

var DEFAULT_PROPERTIES = {
  platform: 'web'
};
/* ServerSide Forwarding values */

var SSF = {
  enabled: 0,
  disabled: 1
};
/* Static anonymousId for users that has not accepted consents */
// const SEGMENT_ID_USER_WITHOUT_CONSENTS = 'id_user_consent_not_agree'

/**
 * Get default properties using the constant and the window.__mpi object if available
 * @returns {{[key:string]: any}} Default properties to attach to track
 */

export var getDefaultProperties = function getDefaultProperties() {
  return _extends({}, DEFAULT_PROPERTIES, getConfig('defaultProperties'));
};
/**
 * Get user traits from global analytics object and put in the object
 * @param {string} gdprPrivacyValue Determine if we have user consents
 * @returns {object} User traits with to add
 */

var mergeUserTraits = function mergeUserTraits(gdprPrivacyValue) {
  // TODO: Disabled for now
  // If user has not accepted GDPR then we should use a static anonymousId
  // if (checkGdprIsAccepted(gdprPrivacyValue)) {
  //   return {
  //     anonymousId: SEGMENT_ID_USER_WITHOUT_CONSENTS
  //   }
  // }
  // If we have user consents, then create the user using anonymousId cookie
  var user = window.analytics.user();
  return {
    anonymousId: user.anonymousId(),
    userId: user.id()
  };
};
/**
 * Get AdobeMarketingCloudVisitorId and merge into the integrations object
 * @param {string} gdprPrivacyValue Tell if user has consents to be tracked
 * @returns {Promise<object>} Integrations with the merged Adobe Analytics needed info
 */


var mergeAdobeAnalyticsIntegrations = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(gdprPrivacyValue) {
    var marketingCloudVisitorId;
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return getAdobeMCVisitorID();

          case 2:
            marketingCloudVisitorId = _context.sent;

            if (marketingCloudVisitorId) {
              _context.next = 5;
              break;
            }

            return _context.abrupt("return", {});

          case 5:
            return _context.abrupt("return", {
              'Adobe Analytics': {
                marketingCloudVisitorId: marketingCloudVisitorId
              }
            });

          case 6:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function mergeAdobeAnalyticsIntegrations(_x) {
    return _ref.apply(this, arguments);
  };
}();
/**
 * Get data like traits and integrations to be added to the context object
 * @param {object} context Context object with all the actual info
 * @returns {Promise<object>} New context with all the previous info and the new one
 */


export var decorateContextWithNeededData = /*#__PURE__*/function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(context) {
    var gdprPrivacyValue, _yield$Promise$all, adobeIntegrations, _yield$Promise$all$, isDMPReady;

    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (context === void 0) {
              context = {};
            }

            _context2.next = 3;
            return getGdprPrivacyValue();

          case 3:
            gdprPrivacyValue = _context2.sent;
            _context2.next = 6;
            return Promise.all([mergeAdobeAnalyticsIntegrations(gdprPrivacyValue) // TODO: Blocking check of DMP is disabled for now
            // checkIsDMPReady()
            ]);

          case 6:
            _yield$Promise$all = _context2.sent;
            adobeIntegrations = _yield$Promise$all[0];
            _yield$Promise$all$ = _yield$Promise$all[1];
            isDMPReady = _yield$Promise$all$ === void 0 ? true : _yield$Promise$all$;
            return _context2.abrupt("return", _extends({}, context, {
              gdpr_privacy: gdprPrivacyValue,
              integrations: _extends({}, context.integrations, adobeIntegrations),
              page: _extends({}, context.page, {
                referrer: getPageReferrer()
              }),
              traits: _extends({}, context.traits, {
                ssf: isDMPReady ? SSF.enabled : SSF.disabled
              }, mergeUserTraits(gdprPrivacyValue))
            }));

          case 11:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function decorateContextWithNeededData(_x2) {
    return _ref2.apply(this, arguments);
  };
}();
/**
 * The track method lets you record any actions your users perform.
 * @param {string} event The name of the event you’re tracking
 * @param {object} [properties] A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */

var track = function track(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  return new Promise(function (resolve, reject) {
    window.analytics.ready( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
      var newContext, newProperties, newCallback;
      return _regeneratorRuntime.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.next = 2;
              return decorateContextWithNeededData(context);

            case 2:
              newContext = _context3.sent;
              newProperties = _extends({}, getDefaultProperties(), properties);

              newCallback = function newCallback() {
                for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
                  args[_key] = arguments[_key];
                }

                if (callback) callback.apply(void 0, args); // eslint-disable-line standard/no-callback-literal

                getAdobeMCVisitorID().then(function (marketingCloudVisitorId) {
                  return syncPixels(marketingCloudVisitorId).then(function () {
                    resolve.apply(void 0, args);
                  });
                })["catch"](reject);
              };

              window.analytics.track(event, newProperties, newContext, newCallback);

            case 6:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3);
    })));
  });
};
/**
 * Associate your users and their actions to a recognizable userId and traits.
 * @param {string} userId Id to identify the user.
 * @param {object} traits A dictionary of traits you know about the user, like their email or name.
 * @param {object} [options] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var identify = function identify(userId, traits, options, callback) {
  return Promise.resolve(window.analytics.identify(userId, traits, options, callback));
};
/**
 * Record whenever a user sees a page of your website, along with any optional properties about the page.
 * It updates automatically the referrer from the context on SPA navigations.
 * @param {string} event The name of the event you’re tracking
 * @param {object} properties A dictionary of properties for the event.
 * @param {object} [context] A dictionary of options.
 * @param {function} [callback] A function executed after a short timeout, giving the browser time to make outbound requests first.
 * @returns {Promise}
 */


var page = function page(event, properties, context, callback) {
  if (context === void 0) {
    context = {};
  }

  updatePageReferrer();
  return track(event, properties, context, callback);
};
/**
 * Resets the id, including anonymousId, and clear traits for the currently identified user and group.
 * NOTE: Only clears the cookies and localStorage set by analytics.
 * @returns {Promise}
 */


var reset = function reset() {
  return Promise.resolve(window.analytics.reset());
};

export default {
  page: page,
  identify: identify,
  track: track,
  reset: reset
};
